"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createSystemCrud = void 0;
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _pubsub = require("@webiny/pubsub");
var _apiSecurity = require("@webiny/api-security");
var _error = _interopRequireDefault(require("@webiny/error"));
const createSystemCrud = ({
  storageOperations,
  getTenantId,
  getIdentity,
  WEBINY_VERSION
}) => {
  return {
    onSystemBeforeInstall: (0, _pubsub.createTopic)("fileManager.onSystemBeforeInstall"),
    onSystemAfterInstall: (0, _pubsub.createTopic)("fileManager.onSystemAfterInstall"),
    async getVersion() {
      const system = await storageOperations.system.get({
        tenant: getTenantId()
      });
      return system ? system.version : null;
    },
    async setVersion(version) {
      const system = await storageOperations.system.get({
        tenant: getTenantId()
      });
      if (system) {
        const data = (0, _objectSpread2.default)((0, _objectSpread2.default)({}, system), {}, {
          tenant: system.tenant || getTenantId(),
          version
        });
        try {
          await storageOperations.system.update({
            original: system,
            data
          });
          return;
        } catch (ex) {
          throw new _error.default("Could not update the system data.", "SYSTEM_UPDATE_ERROR", {
            data
          });
        }
      }
      const data = {
        version,
        tenant: getTenantId()
      };
      try {
        await storageOperations.system.create({
          data
        });
        return;
      } catch (ex) {
        throw new _error.default("Could not create the system data.", "SYSTEM_CREATE_ERROR", {
          data
        });
      }
    },
    async install({
      srcPrefix
    }) {
      const identity = getIdentity();
      if (!identity) {
        throw new _apiSecurity.NotAuthorizedError();
      }
      const version = await this.getVersion();
      if (version) {
        throw new _error.default("File Manager is already installed.", "FILES_INSTALL_ABORTED");
      }
      const data = {};
      if (srcPrefix) {
        data.srcPrefix = srcPrefix;
      }
      await this.onSystemBeforeInstall.publish({});
      await this.createSettings(data);
      await this.setVersion(WEBINY_VERSION);
      await this.onSystemAfterInstall.publish({});
      return true;
    }
  };
};
exports.createSystemCrud = createSystemCrud;