import { Plugin } from "@webiny/plugins";
import { File } from "../types";
export interface FileStorageTransformPluginToParams {
    /**
     * File that is being sent to the storage operations method.
     */
    file: File & Record<string, any>;
}
export interface FileStorageTransformPluginFromParams {
    /**
     * File that was fetched from the storage operations method.
     */
    file: File & Record<string, any>;
}
export interface FileStorageTransformPluginParams {
    toStorage?: (params: FileStorageTransformPluginToParams) => Promise<File & Record<string, any>>;
    fromStorage?: (params: FileStorageTransformPluginFromParams) => Promise<File & Record<string, any>>;
}
export declare class FileStorageTransformPlugin extends Plugin {
    static readonly type: string;
    private readonly _params;
    constructor(params: FileStorageTransformPluginParams);
    /**
     * Transform the file value into something that can be stored.
     * Be aware that you must return the whole file object.
     */
    toStorage(params: FileStorageTransformPluginToParams): Promise<File & Record<string, any>>;
    /**
     * Transform the file value from the storage type to one required by our system.
     * Be aware that you must return the whole file object.
     * This method MUST reverse what ever toStorage method changed on the file object.
     */
    fromStorage(params: FileStorageTransformPluginFromParams): Promise<File & Record<string, any>>;
}
